@@ -247,6 +247,9 @@ def plot(mode, all_para_combination={}, subchart_settings={}, number_of_curves=2
     if mode == 'aggregate':
         app = aggregate.Aggregate(risk_free_rate)
 
+    if mode == 'signal_analysis':
+        app = signals.Signals( all_para_combination, generate_filepath, subchart_settings)
+
     return app
 
 
