@@ -213,6 +213,15 @@ class Components:
 
         return radioitems_div
 
+    def selection_title(self, para_dict, values):
+        title = []
+        for i, key in enumerate(para_dict):
+            title.append(dbc.Row(
+                [dbc.Col(key, width=6),
+                 dbc.Col(f'{values[i]}', style={'text-align': 'center'}, width=6)]))
+
+        return title
+
 
     def update_performance_matrix(self, start_date,end_date,df,para_dict, risk_free_rate, ref_code):
         per_col1 =[]
