@@ -5,11 +5,20 @@ class Signals:
     # Settings
     chart_bg = '#1f2c56'
 
-    def __new__(self, filename, output_folder, start_date, end_date, para_dict, generate_filepath, settings):
+    def __new__(self, all_para_combination, generate_filepath, settings):
 
         chart_bg = self.chart_bg
-        components = Components()
+        components = Components(0)
         empty_line_chart = components.empty_line_chart()
+        para_dict = all_para_combination[0]['para_dict']
+
+        para_combination_list = []
+        for para in all_para_combination:
+            para_list = []
+            for i, key in enumerate(para_dict):
+                para_list.append(para[key])
+            para_combination_list.append(para_list)
+
         radioitems_div = components.generate_radioitems(para_dict)
         period = settings['histogram_period']
         stat_ = ['---', '---', '---', '---', '---']
@@ -130,20 +139,30 @@ class Signals:
             if None in para_radioitems:
                 return title_area, stat_area, line_chart, hist_area
 
-            save_path = generate_filepath(para_combination=para_radioitems)
+            index = para_combination_list.index(para_radioitems)
+            file_path = generate_filepath(para_combination=all_para_combination[index])
+
+            file_format = all_para_combination[index]['file_format']
+
+            if file_format == 'csv':
+                df = pd.read_csv(file_path)
+            elif file_format == 'parquet':
+                df = pd.read_parquet(file_path)
 
-            df = pd.read_csv(save_path)
 
             # Count number of subchart
             subchart_count = 0
             try:
                 fig = settings['subchart_1']
                 subchart_count += 1
-            except Exception as e: pass
+            except Exception as e:
+                pass
+
             try:
                 fig = settings['subchart_2']
                 subchart_count += 1
-            except Exception as e: pass
+            except Exception as e:
+                pass
 
             if subchart_count == 0:
                 row_height = [1]
